==> eam-wshub-proxyclient-11.5-3-sources.jar: net/datastream/schemas/mp_fields/ACTIVITYCODE.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.XmlValue;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;simpleContent>
 *     &lt;extension base="&lt;http://www.w3.org/2001/XMLSchema>long">
 *       &lt;attribute name="auto_generated" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *     &lt;/extension>
 *   &lt;/simpleContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "value"
})
@XmlRootElement(name = "ACTIVITYCODE")
public class ACTIVITYCODE {

    @XmlValue
    protected long value;
    @XmlAttribute(name = "auto_generated")
    protected String auto_Generated;

    /**
     * Obtient la valeur de la propriété value.
     * 
     */
    public long getValue() {
        return value;
    }

    /**
     * Définit la valeur de la propriété value.
     * 
     */
    public void setValue(long value) {
        this.value = value;
    }

    /**
     * Obtient la valeur de la propriété auto_Generated.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAuto_Generated() {
        if (auto_Generated == null) {
            return "false";
        } else {
            return auto_Generated;
        }
    }

    /**
     * Définit la valeur de la propriété auto_Generated.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAuto_Generated(String value) {
        this.auto_Generated = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/ACTIVITYCODE.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.XmlValue;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;simpleContent>
 *     &lt;extension base="&lt;http://www.w3.org/2001/XMLSchema>long">
 *       &lt;attribute name="auto_generated" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *     &lt;/extension>
 *   &lt;/simpleContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "value"
})
@XmlRootElement(name = "ACTIVITYCODE")
public class ACTIVITYCODE {

    @XmlValue
    protected long value;
    @XmlAttribute(name = "auto_generated")
    protected String auto_Generated;

    /**
     * Gets the value of the value property.
     * 
     */
    public long getValue() {
        return value;
    }

    /**
     * Sets the value of the value property.
     * 
     */
    public void setValue(long value) {
        this.value = value;
    }

    /**
     * Gets the value of the auto_Generated property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAuto_Generated() {
        if (auto_Generated == null) {
            return "false";
        } else {
            return auto_Generated;
        }
    }

    /**
     * Sets the value of the auto_Generated property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAuto_Generated(String value) {
        this.auto_Generated = value;
    }

}
